@@ -10,6 +10,7 @@ use Dancer::Plugin::Auth::Extensible;
 
 use Interchange6::Class;
 use Interchange6::Cart;
+use Dancer::Plugin::Interchange6::Cart::DBIC;
 use Dancer::Plugin::Interchange6::Business::OnlinePayment;
 
 =head1 NAME
@@ -18,11 +19,11 @@ Dancer::Plugin::Interchange6 - Interchange6 Shop Plugin for Dancer
 
 =head1 VERSION
 
-Version 0.009
+Version 0.010
 
 =cut
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 =head1 REQUIREMENTS
 
@@ -267,15 +268,6 @@ register shop_charge => sub {
         die "Settings for provider $provider missing.";
     }
 
-    # create BOP object wrapper with provider settings
-	$bop_object = Dancer::Plugin::Interchange6::Business::OnlinePayment->new($provider, %$provider_settings);
-
-    # call charge method
-    debug "Charging with the following parameters: ", \%args;
-
-    # log request
-    $schema = _shop_schema();
-
     my %payment_data = (payment_mode => $provider,
                         status => 'request',
                         sessions_id => session->id,
@@ -284,8 +276,19 @@ register shop_charge => sub {
                         users_id => session('logged_in_user_id'),
                         );
 
+    # create payment order
+    $schema = _shop_schema();
+
     my $payment_order = $schema->resultset('PaymentOrder')->create(\%payment_data);
 
+    # create BOP object wrapper with provider settings
+	$bop_object = Dancer::Plugin::Interchange6::Business::OnlinePayment->new($provider, %$provider_settings);
+
+    $bop_object->payment_order($payment_order);
+
+    # call charge method
+    debug "Charging with the following parameters: ", \%args;
+
     $bop_object->charge(%args);
 
     if ($bop_object->is_success) {
@@ -314,7 +317,7 @@ sub _shop_cart {
         $name = $_[0];
     }
 
-    $cart = Interchange6::Class->instantiate('Dancer::Plugin::Interchange6::Cart::DBIC',
+    $cart = Dancer::Plugin::Interchange6::Cart::DBIC->new(
                                        name => $name,
                                        sessions_id => session->id,
                                        execute_hook => sub {execute_hook(@_)},
